import { AxiosInstance } from 'axios';
import { AxiosRequestConfig } from 'axios';
import { AxiosResponse } from 'axios';
import { ComputedRef } from '@vue/runtime-core';
import { PromiseResultFactory } from 'vue-composable';
import { Ref } from '@vue/runtime-core';

declare interface AxiosReturn<TData> extends PromiseResultFactory<Promise<AxiosResponse<TData>>, [AxiosRequestConfig | string]> {
    readonly client: Ref<Readonly<AxiosInstance>>;
    readonly data: ComputedRef<TData | null>;
    readonly status: Ref<number | null>;
    readonly statusText: Ref<string | null>;
    cancel: (message?: string) => void;
    readonly isCancelled: Ref<boolean>;
    readonly cancelledMessage: Ref<string | null | undefined>;
}

export declare function makeAxios(client: AxiosInstance, throwException?: boolean): {
    client: AxiosInstance;
    data: import("@vue/reactivity").ComputedRef<any>;
    status: import("@vue/reactivity").ComputedRef<number>;
    statusText: import("@vue/reactivity").ComputedRef<string>;
    cancel: (message?: string | undefined) => void;
    isCancelled: import("@vue/reactivity").Ref<false> | import("@vue/reactivity").Ref<true>;
    cancelledMessage: import("@vue/reactivity").Ref<undefined> | import("@vue/reactivity").Ref<null> | import("@vue/reactivity").Ref<string>;
    exec: (request: string | AxiosRequestConfig) => Promise<AxiosResponse<any> | undefined>;
    promise: import("@vue/reactivity").Ref<Promise<AxiosResponse<any>> | undefined>;
    result: import("@vue/reactivity").Ref<AxiosResponse<any> | null>;
    loading: import("@vue/reactivity").Ref<boolean>;
    error: import("@vue/reactivity").Ref<any>;
};

export declare function useAxios<TData = any>(throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(url: string, config?: AxiosRequestConfig, throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(url: string, throwException?: boolean): AxiosReturn<TData>;

export declare function useAxios<TData = any>(config?: AxiosRequestConfig, throwException?: boolean): AxiosReturn<TData>;

export { }
